@@ -20,8 +20,8 @@
 /* Define to the name of the distribution.  */
 #undef PACKAGE
 
-/* The concatenation of the strings PACKAGE, "-", and VERSION.  */
-#undef PACKAGE_VERSION
+/* The concatenation of the strings "GNU ", and PACKAGE.  */
+#undef GNU_PACKAGE
 
 /* Define to 1 if ANSI function prototypes are usable.  */
 #undef PROTOTYPES
