@@ -78,6 +78,7 @@ Compare sorted files LEFT_FILE and RIGHT_FILE line by line.\n\
       --help      display this help and exit\n\
       --version   output version information and exit\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -249,7 +250,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("comm - %s\n", PACKAGE_VERSION);
+      printf ("comm (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
