@@ -972,7 +972,8 @@ process_regexp (struct control *p, int repetition)
   if (!ignore)
     close_output_file ();
 
-  current_line = break_line;
+  if (p->offset > 0)
+    current_line = break_line;
 }
 
 /* Split the input file according to the control records we have built. */
@@ -1518,7 +1519,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("csplit - %s\n", PACKAGE_VERSION);
+      printf ("csplit (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
@@ -1586,6 +1587,7 @@ Read standard input if FILE is -.  Each PATTERN may be:\n\
 \n\
 A line OFFSET is a required `+' or `-' followed by a positive integer.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
