@@ -93,6 +93,7 @@ standard output.\n\
   -s, --spaces        break at spaces\n\
   -w, --width=WIDTH   use WIDTH columns instead of 80\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -309,7 +310,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("fold - %s\n", PACKAGE_VERSION);
+      printf ("fold (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
