@@ -229,6 +229,7 @@ FORMAT is one of:\n\
   rz   right justified, leading zeros\n\
 \n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -578,7 +579,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("nl - %s\n", PACKAGE_VERSION);
+      printf ("nl (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
