@@ -27,7 +27,9 @@
 #include <sys/types.h>
 #include <signal.h>
 #include <stdio.h>
-#define NDEBUG 1
+#ifndef ENABLE_ASSERTIONS
+# define NDEBUG 1
+#endif
 #include <assert.h>
 #include "system.h"
 #include "long-options.h"
@@ -219,8 +221,6 @@ Usage: %s [OPTION]... [FILE]...\n\
 Write sorted concatenation of all FILE(s) to standard output.\n\
 \n\
   +POS1 [-POS2]    start a key at POS1, end it before POS2\n\
-  -M               compare (unknown) < `JAN' < ... < `DEC', imply -b\n\
-  -T DIRECT        use DIRECT for temporary files, not $TMPDIR or %s\n\
   -b               ignore leading blanks in sort fields or keys\n\
   -c               check if given files already sorted, do not sort\n\
   -d               consider only [a-zA-Z0-9 ] characters in keys\n\
@@ -229,11 +229,13 @@ Write sorted concatenation of all FILE(s) to standard output.\n\
   -i               consider only [\\040-\\0176] characters in keys\n\
   -k POS1[,POS2]   same as +POS1 [-POS2], but all positions counted from 1\n\
   -m               merge already sorted files, do not sort\n\
+  -M               compare (unknown) < `JAN' < ... < `DEC', imply -b\n\
   -n               compare according to string numerical value, imply -b\n\
   -o FILE          write result on FILE instead of standard output\n\
   -r               reverse the result of comparisons\n\
   -s               stabilize sort by disabling last resort comparison\n\
   -t SEP           use SEParator instead of non- to whitespace transition\n\
+  -T DIRECT        use DIRECT for temporary files, not $TMPDIR or %s\n\
   -u               with -c, check for strict ordering\n\
   -u               with -m, only output the first of an equal sequence\n\
   -z               end lines with 0 byte, not newline, for find -print0\n\
@@ -247,6 +249,7 @@ for that key.  If no key given, use the entire line as key.  With no\n\
 FILE, or when FILE is -, read standard input.\n\
 ")
 	      , DEFAULT_TMPDIR);
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   /* Don't use EXIT_FAILURE here in case it is defined to be 1.
      POSIX requires that sort return 1 IFF invoked with -c and
@@ -759,7 +762,8 @@ findlines (struct buffer *buf, struct lines *lines)
 static int
 fraccompare (register const char *a, register const char *b)
 {
-  register tmpa = UCHAR (*a), tmpb = UCHAR (*b);
+  register int tmpa = UCHAR (*a);
+  register int tmpb = UCHAR (*b);
 
   if (tmpa == '.' && tmpb == '.')
     {
@@ -986,7 +990,8 @@ getmonth (const char *s, int len)
 static int
 keycompare (const struct line *a, const struct line *b)
 {
-  register char *texta, *textb, *lima, *limb, *translate;
+  register char *texta, *textb, *lima, *limb;
+  register unsigned char *translate;
   register int *ignore;
   struct keyfield *key;
   int diff = 0, iter = 0, lena, lenb;
@@ -994,7 +999,7 @@ keycompare (const struct line *a, const struct line *b)
   for (key = keyhead.next; key; key = key->next, ++iter)
     {
       ignore = key->ignore;
-      translate = key->translate;
+      translate = (unsigned char *) key->translate;
 
       /* Find the beginning and limit of each field. */
       if (iter || a->keybeg == NULL || b->keybeg == NULL)
@@ -1136,7 +1141,7 @@ keycompare (const struct line *a, const struct line *b)
 
 	CMP_WITH_IGNORE (translate[UCHAR (*texta)], translate[UCHAR (*textb)]);
       else if (ignore)
-	CMP_WITH_IGNORE (*texta, *textb);
+	CMP_WITH_IGNORE (UCHAR (*texta), UCHAR (*textb));
       else if (translate)
 	while (texta < lima && textb < limb)
 	  {
@@ -1245,12 +1250,16 @@ checkfp (FILE *fp)
 
       /* Save the last line of the buffer and refill the buffer. */
       prev_line = lines.lines + (lines.used - 1);
-      if (prev_line->length > alloc)
+      if (prev_line->length + 1 > alloc)
 	{
-	  while (prev_line->length + 1 > alloc)
-	    alloc *= 2;
+	  do
+	    {
+	      alloc *= 2;
+	    }
+	  while (alloc < prev_line->length + 1);
 	  temp.text = xrealloc (temp.text, alloc);
 	}
+      assert (prev_line->length + 1 <= alloc);
       memcpy (temp.text, prev_line->text, prev_line->length + 1);
       temp.length = prev_line->length;
       temp.keybeg = temp.text + (prev_line->keybeg - prev_line->text);
@@ -1687,10 +1696,6 @@ set_ordering (register const char *s, struct keyfield *key,
 	  break;
 	case 'n':
 	  key->numeric = 1;
-	  if (blanktype == bl_start || blanktype == bl_both)
-	    key->skipsblanks = 1;
-	  if (blanktype == bl_end || blanktype == bl_both)
-	    key->skipeblanks = 1;
 	  break;
 	case 'r':
 	  key->reverse = 1;
@@ -1703,6 +1708,13 @@ set_ordering (register const char *s, struct keyfield *key,
   return (char *) s;
 }
 
+static void
+key_init (struct keyfield *key)
+{
+  memset (key, 0, sizeof (*key));
+  key->eword = -1;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -1721,7 +1733,7 @@ main (int argc, char **argv)
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
-  parse_long_options (argc, argv, "sort", PACKAGE_VERSION, usage);
+  parse_long_options (argc, argv, "sort", GNU_PACKAGE, VERSION, usage);
 
   have_read_stdin = 0;
   inittables ();
@@ -1773,11 +1785,7 @@ main (int argc, char **argv)
 	  if (key)
 	    insertkey (key);
 	  key = (struct keyfield *) xmalloc (sizeof (struct keyfield));
-	  key->eword = -1;
-	  key->ignore = NULL;
-	  key->translate = NULL;
-	  key->skipsblanks = key->skipeblanks = 0;
-	  key->numeric = key->general_numeric = key->month = key->reverse = 0;
+	  key_init (key);
 	  s = argv[i] + 1;
 	  if (! (digits[UCHAR (*s)] || (*s == '.' && digits[UCHAR (s[1])])))
 	    badfieldspec (argv[i]);
@@ -1850,11 +1858,7 @@ key specifiers,\nthe +POS specifier must come first"));
 		      insertkey (key);
 		    key = (struct keyfield *)
 		      xmalloc (sizeof (struct keyfield));
-		    key->eword = -1;
-		    key->ignore = NULL;
-		    key->translate = NULL;
-		    key->skipsblanks = key->skipeblanks = 0;
-		    key->numeric = key->month = key->reverse = 0;
+		    key_init (key);
 		    /* Get POS1. */
 		    if (!digits[UCHAR (*s)])
 		      badfieldspec (argv[i]);
