@@ -168,6 +168,25 @@ char *getenv ();
 
 #include <ctype.h>
 
+/* Jim Meyering writes:
+
+   "... Some ctype macros are valid only for character codes that
+   isascii says are ASCII (SGI's IRIX-4.0.5 is one such system --when
+   using /bin/cc or gcc but without giving an ansi option).  So, all
+   ctype uses should be through macros like ISPRINT...  If
+   STDC_HEADERS is defined, then autoconf has verified that the ctype
+   macros don't need to be guarded with references to isascii. ...
+   Defining isascii to 1 should let any compiler worth its salt
+   eliminate the && through constant folding."
+
+   Bruno Haible adds:
+
+   "... Furthermore, isupper(c) etc. have an undefined result if c is
+   outside the range -1 <= c <= 255. One is tempted to write isupper(c)
+   with c being of type `char', but this is wrong if c is an 8-bit
+   character >= 128 which gets sign-extended to a negative value.
+   The macro ISUPPER protects against this as well."  */
+
 #if defined (STDC_HEADERS) || (!defined (isascii) && !defined (HAVE_ISASCII))
 #define IN_CTYPE_DOMAIN(c) 1
 #else
@@ -217,7 +236,9 @@ char *getenv ();
 # include <libintl.h>
 # define _(Text) gettext (Text)
 #else
+# undef bindtextdomain
 # define bindtextdomain(Domain, Directory) /* empty */
+# undef textdomain
 # define textdomain(Domain) /* empty */
 # define _(Text) Text
 #endif
