@@ -113,13 +113,14 @@ enum Upper_Lower_class
 /* A shortcut to ensure that when constructing the translation array,
    one of the values returned by paired calls to get_next (from s1 and s2)
    is from [:upper:] and the other is from [:lower:], or neither is from
-   upper or lower.  In fact, no other character classes are allowed when
-   translating, but that condition is tested elsewhere.  This array is
-   indexed by values of type enum Upper_Lower_class.  */
+   upper or lower.  By default, GNU tr permits the identity mappings: from
+   [:upper:] to [:upper:] and [:lower:] to [:lower:].  But when
+   POSIXLY_CORRECT is set, those evoke diagnostics. This array is indexed
+   by values of type enum Upper_Lower_class.  */
 static int const class_ok[3][3] =
 {
-  {0, 1, 0},
-  {1, 0, 0},
+  {1, 1, 0},
+  {1, 1, 0},
   {0, 0, 1}
 };
 
@@ -412,6 +413,7 @@ only be used in pairs to specify case conversion.  -s uses SET1 if not\n\
 translating nor deleting; else squeezing uses SET2 and occurs after\n\
 translation or deletion.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -478,6 +480,13 @@ is_char_class_member (enum Char_class char_class, unsigned int c)
   return result;
 }
 
+static void
+es_free (struct E_string *es)
+{
+  free (es->s);
+  free (es->escaped);
+}
+
 /* Perform the first pass over each range-spec argument S, converting all
    \c and \ddd escapes to their one-byte representations.  The conversion
    is done in-place, so S must point to writable storage.  If an invalid
@@ -1206,6 +1215,33 @@ get_next (struct Spec_list *s, enum Upper_Lower_class *class)
       break;
 
     case RE_CHAR_CLASS:
+      if (class)
+	{
+	  int upper_or_lower;
+	  switch (p->u.char_class)
+	    {
+	    case CC_LOWER:
+	      *class = UL_LOWER;
+	      upper_or_lower = 1;
+	      break;
+	    case CC_UPPER:
+	      *class = UL_UPPER;
+	      upper_or_lower = 1;
+	      break;
+	    default:
+	      upper_or_lower = 0;
+	      break;
+	    }
+
+	  if (upper_or_lower)
+	    {
+	      s->tail = p->next;
+	      s->state = NEW_ELEMENT;
+	      return_val = 0;
+	      break;
+	    }
+	}
+
       if (s->state == NEW_ELEMENT)
 	{
 	  for (i = 0; i < N_CHARS; i++)
@@ -1226,21 +1262,6 @@ get_next (struct Spec_list *s, enum Upper_Lower_class *class)
 	  s->tail = p->next;
 	  s->state = NEW_ELEMENT;
 	}
-      if (class)
-	{
-	  switch (p->u.char_class)
-	    {
-	    case CC_LOWER:
-	      *class = UL_LOWER;
-	      break;
-	    case CC_UPPER:
-	      *class = UL_UPPER;
-	      break;
-	    default:
-	      /* empty */
-	      break;
-	    }
-	}
       break;
 
     case RE_EQUIV_CLASS:
@@ -1428,12 +1449,13 @@ static int
 parse_str (const unsigned char *s, struct Spec_list *spec_list)
 {
   struct E_string es;
+  int fail;
 
-  if (unquote (s, &es))
-    return 1;
-  if (build_spec_list (&es, spec_list))
-    return 1;
-  return 0;
+  fail = unquote (s, &es);
+  if (!fail)
+    fail = build_spec_list (&es, spec_list);
+  es_free (&es);
+  return fail;
 }
 
 /* Given two specification lists, S1 and S2, and assuming that
@@ -1586,7 +1608,7 @@ when translating"));
 	    {
 	      error (EXIT_FAILURE, 0,
 		     _("when translating, the only character classes that may \
-appear in\n\tstring2 are `upper' and `lower'"));
+appear in\nstring2 are `upper' and `lower'"));
 	    }
 	}
       else
@@ -1847,7 +1869,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("tr - %s\n", PACKAGE_VERSION);
+      printf ("tr (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
@@ -1980,11 +2002,42 @@ without squeezing repeats"));
 	      c2 = get_next (s2, &class_s2);
 	      if (!class_ok[(int) class_s1][(int) class_s2])
 		error (EXIT_FAILURE, 0,
-		     _("misaligned or mismatched upper and/or lower classes"));
-	      /* The following should have been checked by validate...  */
-	      if (c2 == -1)
-		break;
-	      xlate[c1] = c2;
+		       _("misaligned [:upper:] and/or [:lower:] construct"));
+
+	      if (class_s1 == UL_LOWER && class_s2 == UL_UPPER)
+		{
+		  for (i = 0; i < N_CHARS; i++)
+		    if (ISLOWER (i))
+		      xlate[i] = toupper (i);
+		}
+	      else if (class_s1 == UL_UPPER && class_s2 == UL_LOWER)
+		{
+		  for (i = 0; i < N_CHARS; i++)
+		    if (ISUPPER (i))
+		      xlate[i] = tolower (i);
+		}
+	      else if ((class_s1 == UL_LOWER && class_s2 == UL_LOWER)
+		       || (class_s1 == UL_UPPER && class_s2 == UL_UPPER))
+		{
+		  /* By default, GNU tr permits the identity mappings: from
+		     [:upper:] to [:upper:] and [:lower:] to [:lower:].  But
+		     when POSIXLY_CORRECT is set, those evoke diagnostics.  */
+		  if (posix_pedantic)
+		    {
+		      error (EXIT_FAILURE, 0,
+			     _("\
+invalid identity mapping;  when translating, any [:lower:] or [:upper:]\n\
+construct in string1 must be aligned with a corresponding construct\n\
+([:upper:] or [:lower:], respectively) in string2"));
+		    }
+		}
+	      else
+		{
+		  /* The following should have been checked by validate...  */
+		  if (c2 == -1)
+		    break;
+		  xlate[c1] = c2;
+		}
 	    }
 	  assert (c1 == -1 || truncate_set1);
 	}
